@@ -42,8 +42,9 @@ REFERENCES = [UK_WHO, TRISOMY_21, TURNERS]
 SEXES = ["male", "female"]
 MEASUREMENT_METHODS = ["height", "weight", "ofc", "bmi"]
 
-THREE_PERCENT_CENTILES = 'three_percent_centiles'
-COLE_TWO_THIRDS_SDS_NINE_CENTILES = 'cole_two_thirds_sds_nine_centiles'
+THREE_PERCENT_CENTILES = 'six-centiles'
+COLE_TWO_THIRDS_SDS_NINE_CENTILES = 'nine-centiles'
+CENTILE_FORMATS=[THREE_PERCENT_CENTILES, COLE_TWO_THIRDS_SDS_NINE_CENTILES]
 
 THREE_PERCENT_CENTILE_COLLECTION = [
     3.0, 5.0, 10.0, 25.0, 50.0, 75.0, 90.0, 95.0, 97.0]
